import QtQuick 2.0
import QtQuick.Scene3D 2.0
import Qt3D.Core 2.0
import Qt3D.Render 2.0
import Qt3D.Input 2.0
import Qt3D.Extras 2.0

Scene3D {
    width: 100
    height: 62
    focus: true
    aspects: "input"

    Entity {
        id: sceneRoot

        //property color backgroundColor: Qt.rgba(0, 0.5, 1, 1)
        property color backgroundColor: Qt.rgba(0, 1, 1, 0)

        Camera {
            id: camera
            projectionType: CameraLens.PerspectiveProjection
            fieldOfView: 45
            aspectRatio: 16/9
            nearPlane : 0.1
            farPlane : 1000.0
            position: Qt.vector3d( 0.0, 0.0, -40.0 )
            upVector: Qt.vector3d( 0.0, 1.0, 0.0 )
            viewCenter: Qt.vector3d( 0.0, 0.0, 0.0 )
        }

        FirstPersonCameraController { camera: camera }

        components: [
            RenderSettings {
                RenderSurfaceSelector {
                    ForwardRenderer {
                        camera: camera
                        clearColor: "transparent"
                    }
                }
            }
        ]

        //the pool
        TorusMesh {
            id: torusMesh
            radius: 10
            minorRadius: 4
            rings: 100
            slices: 20
        }

        Transform {
            id: torusTransform
            scale3D: Qt.vector3d(1.5, 1, 0.5)
            rotation: fromAxisAndAngle(Qt.vector3d(1, 0, 0), 45)
        }

        Entity {
            id: torusEntity
            components: [ torusMesh, torusTransform ]
        }
        //END the pool

        //a tree
        Entity {
            id:treeEntity

            property int height_crownBegin: 3
            property int crownRadius: 3

            components: [treeTransform]

            Transform {
                id: treeTransform
                translation: Qt.vector3d(0, -5, 0)
            }

            //treeTop
            SphereMesh {
                id: treeTopMesh
                radius: 3
            }
            Transform {
                id: treeTopTransform //place treeTop on top of treeTrunk (-0.2 to make trunk stick in crown)

                translation: Qt.vector3d(0, (treeEntity.height_crownBegin + treeEntity.crownRadius*0.5)-0.2, 0)
            }
            Entity {
                id: treeTopEntity
                components: [ treeTopMesh, treeTopTransform ]
            }
            CylinderMesh {
                id: treeTrunkMesh
                radius: 1
                length: 3
                rings: 100
                slices: 20
            }
            Entity {
                id: treeTrunkEntity
                components: [ treeTrunkMesh]
            }

        }



        //Sphere -> the sun
        SphereMesh {
            id: sphereMesh
            radius: 3
        }

        Transform {
            id: sphereTransform
            translation: Qt.vector3d(20, 10, 0)
        }

        Entity {
            id: sphereEntity
            components: [ sphereMesh, sphereTransform ]
        }
        //END Sphere
    }
}
